
#ifndef GRAPHTHEORY_EXPORT_H
#define GRAPHTHEORY_EXPORT_H

#ifdef GRAPHTHEORY_STATIC_DEFINE
#  define GRAPHTHEORY_EXPORT
#  define GRAPHTHEORY_NO_EXPORT
#else
#  ifndef GRAPHTHEORY_EXPORT
#    ifdef rocsgraphtheory_EXPORTS
        /* We are building this library */
#      define GRAPHTHEORY_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define GRAPHTHEORY_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef GRAPHTHEORY_NO_EXPORT
#    define GRAPHTHEORY_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef GRAPHTHEORY_DEPRECATED
#  define GRAPHTHEORY_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef GRAPHTHEORY_DEPRECATED_EXPORT
#  define GRAPHTHEORY_DEPRECATED_EXPORT GRAPHTHEORY_EXPORT GRAPHTHEORY_DEPRECATED
#endif

#ifndef GRAPHTHEORY_DEPRECATED_NO_EXPORT
#  define GRAPHTHEORY_DEPRECATED_NO_EXPORT GRAPHTHEORY_NO_EXPORT GRAPHTHEORY_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef GRAPHTHEORY_NO_DEPRECATED
#    define GRAPHTHEORY_NO_DEPRECATED
#  endif
#endif

#endif /* GRAPHTHEORY_EXPORT_H */
